/*
 * libdbi - database independent abstraction layer for C.
 * Copyright (C) 2001-2002, David Parker and Mark Tobenkin.
 * http://libdbi.sourceforge.net
 * 
 * dbd_mysql.c: MySQL database support (using libmysqlclient)
 * Copyright (C) 2001-2002, Mark M. Tobenkin <mark@brentwoodradio.com>.
 * http://libdbi.sourceforge.net
 * 
 * $Id: dbd_mysql.h,v 1.4 2008/03/07 20:51:27 mhoenicka Exp $
 */

#define MYSQL_RESERVED_WORDS { \
	"ACTION", \
	"ADD", \
	"AGGREGATE", \
	"ALL", \
	"ALTER", \
	"AFTER", \
	"AND", \
	"AS", \
	"ASC", \
	"AVG", \
	"AVG_ROW_LENGTH", \
	"AUTO_INCREMENT", \
	"BETWEEN", \
	"BIGINT", \
	"BIT", \
	"BINARY", \
	"BLOB", \
	"BOOL", \
	"BOTH", \
	"BY", \
	"CASCADE", \
	"CASE", \
	"CHAR", \
	"CHARACTER", \
	"CHANGE", \
	"CHECK", \
	"CHECKSUM", \
	"COLUMN", \
	"COLUMNS", \
	"COMMENT", \
	"CONSTRAINT", \
	"CREATE", \
	"CROSS", \
	"CURRENT_DATE", \
	"CURRENT_TIME", \
	"CURRENT_TIMESTAMP", \
	"DATA", \
	"DATABASE", \
	"DATABASES", \
	"DATE", \
	"DATETIME", \
	"DAY", \
	"DAY_HOUR", \
	"DAY_MINUTE", \
	"DAY_SECOND", \
	"DAYOFMONTH", \
	"DAYOFWEEK", \
	"DAYOFYEAR", \
	"DEC", \
	"DECIMAL", \
	"DEFAULT", \
	"DELAYED", \
	"DELAY_KEY_WRITE", \
	"DELETE", \
	"DESC", \
	"DESCRIBE", \
	"DISTINCT", \
	"DISTINCTROW", \
	"DOUBLE", \
	"DROP", \
	"END", \
	"ELSE", \
	"ESCAPE", \
	"ESCAPED", \
	"ENCLOSED", \
	"ENUM", \
	"EXPLAIN", \
	"EXISTS", \
	"FIELDS", \
	"FILE", \
	"FIRST", \
	"FLOAT", \
	"FLOAT4", \
	"FLOAT8", \
	"FLUSH", \
	"FOREIGN", \
	"FROM", \
	"FOR", \
	"FULL", \
	"FUNCTION", \
	"GLOBAL", \
	"GRANT", \
	"GRANTS", \
	"GROUP", \
	"HAVING", \
	"HEAP", \
	"HIGH_PRIORITY", \
	"HOUR", \
	"HOUR_MINUTE", \
	"HOUR_SECOND", \
	"HOSTS", \
	"IDENTIFIED", \
	"IGNORE", \
	"IN", \
	"INDEX", \
	"INFILE", \
	"INNER", \
	"INSERT", \
	"INSERT_ID", \
	"INT", \
	"INTEGER", \
	"INTERVAL", \
	"INT1", \
	"INT2", \
	"INT3", \
	"INT4", \
	"INT8", \
	"INTO", \
	"IF", \
	"IS", \
	"ISAM", \
	"JOIN", \
	"KEY", \
	"KEYS", \
	"KILL", \
	"LAST_INSERT_ID", \
	"LEADING", \
	"LEFT", \
	"LENGTH", \
	"LIKE", \
	"LINES", \
	"LIMIT", \
	"LOAD", \
	"LOCAL", \
	"LOCK", \
	"LOGS", \
	"LONG", \
	"LONGBLOB", \
	"LONGTEXT", \
	"LOW_PRIORITY", \
	"MAX", \
	"MAX_ROWS", \
	"MATCH", \
	"MEDIUMBLOB", \
	"MEDIUMTEXT", \
	"MEDIUMINT", \
	"MIDDLEINT", \
	"MIN_ROWS", \
	"MINUTE", \
	"MINUTE_SECOND", \
	"MODIFY", \
	"MONTH", \
	"MONTHNAME", \
	"MYISAM", \
	"NATURAL", \
	"NUMERIC", \
	"NO", \
	"NOT", \
	"NULL", \
	"ON", \
	"OPTIMIZE", \
	"OPTION", \
	"OPTIONALLY", \
	"OR", \
	"ORDER", \
	"OUTER", \
	"OUTFILE", \
	"PACK_KEYS", \
	"PARTIAL", \
	"PASSWORD", \
	"PRECISION", \
	"PRIMARY", \
	"PROCEDURE", \
	"PROCESS", \
	"PROCESSLIST", \
	"PRIVILEGES", \
	"READ", \
	"REAL", \
	"REFERENCES", \
	"RELOAD", \
	"REGEXP", \
	"RENAME", \
	"REPLACE", \
	"RESTRICT", \
	"RETURNS", \
	"REVOKE", \
	"RLIKE", \
	"ROW", \
	"ROWS", \
	"SECOND", \
	"SELECT", \
	"SET", \
	"SHOW", \
	"SHUTDOWN", \
	"SMALLINT", \
	"SONAME", \
	"SQL_BIG_TABLES", \
	"SQL_BIG_SELECTS", \
	"SQL_LOW_PRIORITY_UPDATES", \
	"SQL_LOG_OFF", \
	"SQL_LOG_UPDATE", \
	"SQL_SELECT_LIMIT", \
	"SQL_SMALL_RESULT", \
	"SQL_BIG_RESULT", \
	"SQL_WARNINGS", \
	"STRAIGHT_JOIN", \
	"STARTING", \
	"STATUS", \
	"STRING", \
	"TABLE", \
	"TABLES", \
	"TEMPORARY", \
	"TERMINATED", \
	"TEXT", \
	"THEN", \
	"TIME", \
	"TIMESTAMP", \
	"TINYBLOB", \
	"TINYTEXT", \
	"TINYINT", \
	"TRAILING", \
	"TO", \
	"TYPE", \
	"USE", \
	"USING", \
	"UNIQUE", \
	"UNLOCK", \
	"UNSIGNED", \
	"UPDATE", \
	"USAGE", \
	"VALUES", \
	"VARCHAR", \
	"VARIABLES", \
	"VARYING", \
	"VARBINARY", \
	"WITH", \
	"WRITE", \
	"WHEN", \
	"WHERE", \
	"YEAR", \
	"YEAR_MONTH", \
	"ZEROFILL", \
	NULL }

#define MYSQL_CUSTOM_FUNCTIONS { \
        "my_init", \
        "mysql_affected_rows", \
        "mysql_autocommit", \
        "mysql_change_user", \
        "mysql_character_set_name", \
        "mysql_close", \
        "mysql_commit", \
        "mysql_connect", \
        "mysql_create_db", \
        "mysql_data_seek", \
        "mysql_debug", \
        "mysql_drop_db", \
        "mysql_dump_debug_info", \
        "mysql_eof", \
        "mysql_errno", \
        "mysql_error", \
        "mysql_escape_string", \
        "mysql_fetch_field", \
        "mysql_fetch_field_direct", \
        "mysql_fetch_fields", \
        "mysql_fetch_lengths", \
        "mysql_fetch_row", \
        "mysql_field_count", \
        "mysql_field_seek", \
        "mysql_field_tell", \
        "mysql_free_result", \
        "mysql_get_character_set_info", \
        "mysql_get_client_info", \
        "mysql_get_client_version", \
        "mysql_get_host_info", \
        "mysql_get_proto_info", \
        "mysql_get_server_info", \
        "mysql_get_server_version", \
        "mysql_get_ssl_cipher", \
        "mysql_hex_string", \
        "mysql_info", \
        "mysql_init", \
        "mysql_insert_id", \
        "mysql_kill", \
        "mysql_library_end", \
        "mysql_library_init", \
        "mysql_list_dbs", \
        "mysql_list_fields", \
        "mysql_list_processes", \
        "mysql_list_tables", \
        "mysql_more_results", \
        "mysql_next_result", \
        "mysql_num_fields", \
        "mysql_num_rows", \
        "mysql_options", \
        "mysql_ping", \
        "mysql_query", \
        "mysql_real_connect", \
        "mysql_real_escape_string", \
        "mysql_real_query", \
        "mysql_refresh", \
        "mysql_reload", \
        "mysql_rollback", \
        "mysql_row_seek", \
        "mysql_row_tell", \
        "mysql_select_db", \
        "mysql_server_end", \
        "mysql_server_init", \
        "mysql_set_character_set", \
        "mysql_set_local_infile_default", \
        "mysql_set_local_infile_handler", \
        "mysql_set_server_option", \
        "mysql_sqlstate", \
        "mysql_shutdown", \
        "mysql_ssl_set", \
        "mysql_stat", \
        "mysql_store_result", \
        "mysql_thread_end", \
        "mysql_thread_id", \
        "mysql_thread_init", \
        "mysql_thread_safe", \
        "mysql_use_result", \
        "mysql_warning_count", \
        NULL}
